@@ -1,4 +1,4 @@
-plot.bayesm.hcoef=function(x,burnin=trunc(.1*R),...){
+plot.bayesm.hcoef=function(x,names,burnin=trunc(.1*R),...){
 #
 # S3 method to plot arrays of draws of coefs in hier models
 #   3 dimensional arrays:  unit x var x draw
@@ -18,6 +18,7 @@ plot.bayesm.hcoef=function(x,burnin=trunc(.1*R),...){
   #
   #  plot posterior distributions of nvar coef for 30 rand units
   #
+  if(missing(names)) {names=as.character(1:nvar)}
   rsam=sort(sample(c(1:nunits),30))  # randomly sample 30 cross-sectional units
   par(mfrow=c(1,1))
   par(las=3)  # horizontal labeling
@@ -26,7 +27,7 @@ plot.bayesm.hcoef=function(x,burnin=trunc(.1*R),...){
        colnames(ext)=as.character(rsam)
        out=boxplot(ext,plot=FALSE,...)
        out$stats=apply(ext,2,quantile,probs=c(0,.05,.95,1))
-       bxp(out,xlab="Cross-sectional Unit",main=paste("Coefficients on Var ",var,sep=""),boxfill="magenta",...)
+       bxp(out,xlab="Cross-sectional Unit",main=paste("Coefficients on Var ",names[var],sep=""),boxfill="magenta",...)
        if(var==1) par(ask=dev.interactive())
   }
   #
@@ -37,7 +38,7 @@ plot.bayesm.hcoef=function(x,burnin=trunc(.1*R),...){
   for(i in 1:nunits) pmeans[i,]=apply(X[i,,(burnin+1):R],1,mean)
   names=as.character(1:nvar)
   attributes(pmeans)$class="bayesm.mat"
-  for(i in 1:nvar) names[i]=paste("Posterior Means of Coef ",i,sep="")
+  for(i in 1:nvar) names[i]=paste("Posterior Means of Coef ",names[var],sep="")
   plot(pmeans,names,TRACEPLOT=FALSE,INT=FALSE,DEN=FALSE,CHECK_NDRAWS=FALSE,...)
 invisible()
 }
